# log_ip
python script that dumps your IP into a log file
https://github.com/FrenchCommando/log_ip

## Dependency
- python 3 - currently working with 3.7

## Usage

### using pip
- pip install log-ip
  - run in cmd : log-ip
  
## Contribution
Anything is always welcome


[Github](https://github.com/FrenchCommando/log_ip)